@@ -1,29 +1,14 @@
-/*
- * This file is part of gspell, a spell-checking library.
- *
- * Copyright 2015, 2016, 2020 - Sébastien Wilmet <swilmet@gnome.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+/* SPDX-FileCopyrightText: 2015, 2016, 2020 - Sébastien Wilmet <swilmet@gnome.org>
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 /* Init i18n */
 
 /* Part of the code taken from the GtkSourceView library (gtksourceview-i18n.c).
- * Copyright (C) 1997, 1998, 1999, 2000 Free Software Foundation
+ * SPDX-FileCopyrightText: (C) 1997, 1998, 1999, 2000 Free Software Foundation
  */
 
-#include "config.h"
+#include "gspell-config.h"
 #include <glib/gi18n-lib.h>
 #include "gconstructor.h"
 
