@@ -1,35 +1,17 @@
-/*
- * This file is part of gspell, a spell-checking library.
- *
- * Copyright 2006 - Paolo Maggi
- * Copyright 2008 - Novell, Inc.
- * Copyright 2015, 2016, 2020 - Sébastien Wilmet
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+/* SPDX-FileCopyrightText: 2006 - Paolo Maggi
+ * SPDX-FileCopyrightText: 2008 - Novell, Inc.
+ * SPDX-FileCopyrightText: 2015, 2016, 2020 - Sébastien Wilmet
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
+#include "gspell-config.h"
 #include "gspell-language.h"
 #include <string.h>
 #include <glib/gi18n-lib.h>
 #include <enchant.h>
 #include "gspell-icu.h"
 
-#ifdef OS_OSX
+#if OS_MACOS
 #include "gspell-osx.h"
 #endif
 
@@ -156,7 +138,7 @@ gspell_language_get_default (void)
 	}
 
 	/* Another try specific to Mac OS X */
-#ifdef OS_OSX
+#if OS_MACOS
 	{
 		gchar *code = _gspell_osx_get_preferred_spell_language ();
 
